==> linux-gpib-1.1b.base.tgz: linux-gpib/driver/sys/ibsys.h <==


#include <gpibP.h>



#include <linux/config.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/tty.h>
#include <linux/signal.h>
#include <linux/errno.h>
#include <linux/major.h>
#include <linux/module.h>
#include <linux/malloc.h>
#include <linux/mm.h>
#include <linux/timer.h>

#ifdef CONFIG_DMA_MEM_PERM
#include <linux/dma_mem.h>
#endif

#include <asm/io.h>
#include <asm/segment.h>
#include <asm/system.h>
#include <asm/irq.h>
#include <asm/dma.h>

#ifndef IBMAJOR
/* default value for major number */
#define IBMAJOR 31
#endif

#define LINUX_VERS	1
#define LINUX_PATCH	51

#define DEFAULT_GPIB_DMA_SIZE	0


 #define DMA_PAGE_SIZE (128*1024)       /* Page Boundaries for channel 5-7 transfers */
 #define MAX_DMA_MEMORY (16*1024*1024)  /* DMA transfers limited to lower 16M */

 #ifdef CONFIG_DMA_MEM_PERM
  #define MAX_DMA_SIZE	(128*1024)	/* Maximum DMA transfer size 	*/
 #else
  #define MAX_DMA_SIZE	(63*1024)	/* Maximum DMA transfer size 	*/
 #endif


#define TICKSPERSEC 100
#define OK 0



extern uint16      ibbase;	/* base addr of GPIB interface registers  */
extern uint8       ibirq;	/* interrupt request line for GPIB (1-7)  */
extern uint8       ibdma ;      /* DMA channel                            */


extern ibregs_t *ib;            /* Local pointer to IB registers */

extern int pgmstat;
extern volatile int noTimo;
extern uint32 timeTable[];


extern struct wait_queue *ibwait_queue;

#if HAS_SEMAPHORES
extern struct semaphore espsemid;		/* semaphore ID for ESP interrupt support */
#else
extern int       espsemid;		/* semaphore ID for ESP interrupt support */
#endif

#if HAS_DMAMANAGER
extern char  *gpib_dma_buffer;
extern int   gpib_dma_size;
extern int   gpib_default_dma_size;
#endif

#define IB ib              


/* if dma flag not present (kernels < 1.2.0) disable it */

#if !defined (GFP_DMA) || 1
#define MEMORY_PRIORITY (GFP_KERNEL)
#else
#error does not work correctly
#define GFP_DMA_DEFINED
#define MEMORY_PRIORITY (GFP_ATOMIC | GFP_DMA)

#endif

==> linux-gpib-1.3a.base.tgz: linux-gpib/driver/sys/ibsys.h <==
#include <gpibP.h>



#include <linux/config.h>
#include <linux/kernel.h>
#include <linux/sched.h>
#include <linux/tty.h>
#include <linux/signal.h>
#include <linux/errno.h>
#include <linux/major.h>
#include <linux/module.h>
#include <linux/malloc.h>
#include <linux/mm.h>
#include <linux/timer.h>

#ifdef CONFIG_DMA_MEM_PERM
#include <linux/dma_mem.h>
#endif

#include <asm/io.h>
#include <asm/segment.h>
#include <asm/system.h>
#include <asm/irq.h>
#include <asm/dma.h>

#ifndef IBMAJOR
/* default value for major number */
#define IBMAJOR 31
#endif

#define LINUX_VERS	1
#define LINUX_PATCH	51

#define DEFAULT_GPIB_DMA_SIZE	0


 #define DMA_PAGE_SIZE (128*1024)       /* Page Boundaries for channel 5-7 transfers */
 #define MAX_DMA_MEMORY (16*1024*1024)  /* DMA transfers limited to lower 16M */

 #ifdef CONFIG_DMA_MEM_PERM
  #define MAX_DMA_SIZE	(128*1024)	/* Maximum DMA transfer size 	*/
 #else
  #define MAX_DMA_SIZE	(63*1024)	/* Maximum DMA transfer size 	*/
 #endif


#define TICKSPERSEC 100
#define OK 0



extern uint16      ibbase;	/* base addr of GPIB interface registers  */
extern uint8       ibirq;	/* interrupt request line for GPIB (1-7)  */
extern uint8       ibdma ;      /* DMA channel                            */


extern ibregs_t *ib;            /* Local pointer to IB registers */

extern int pgmstat;
extern volatile int noTimo;
extern uint32 timeTable[];


extern struct wait_queue *ibwait_queue;

#if HAS_SEMAPHORES
extern struct semaphore espsemid;		/* semaphore ID for ESP interrupt support */
#else
extern int       espsemid;		/* semaphore ID for ESP interrupt support */
#endif

extern char  *gpib_dma_buffer;
extern int   gpib_dma_size;
extern int   gpib_default_dma_size;

#define IB ib              


/* if dma flag not present (kernels < 1.2.0) disable it */

#if defined(GFP_DMA) 

#define GFP_DMA_DEFINED
#define MEMORY_PRIORITY (GFP_KERNEL | GFP_DMA)
#else
#define MEMORY_PRIORITY (GFP_KERNEL)

#endif
